Data Writers
============

Time-Series FITS
----------------
.. automodule:: lsl.writer.tsfits
   :members:
   :inherited-members:

Single-Dish FITS
----------------
`SDFITS Standard <http://fits.gsfc.nasa.gov/registry/sdfits.html>`_

.. automodule:: lsl.writer.sdfits
   :members:
   :inherited-members:

FITS IDI
--------
`FITS IDI Standard <http://fits.gsfc.nasa.gov/registry/fitsidi.html>`_

.. automodule:: lsl.writer.fitsidi
   :members:

UVFITS
------
.. automodule:: lsl.writer.uvfits
   :members:

Measurement Set
---------------
.. automodule:: lsl.writer.measurementset
   :members:

VDIF
----
`VDIF Standard <http://www.vlbi.org/vdif/docs/VDIF%20specification%20Release%201.0%20ratified.pdf>`_ (PDF)

.. automodule:: lsl.writer.vdif
   :members:

